@@ -363,7 +363,6 @@ class WithTest(CoverageTest):
             branchz_missing="",
         )
 
-
     def test_multi_multiline_with(self) -> None:
         # https://github.com/nedbat/coveragepy/issues/1880
         self.check_coverage("""\
@@ -382,6 +381,22 @@ class WithTest(CoverageTest):
             branchz_missing="",
         )
 
+    def test_multi_multiline_with_backslask(self) -> None:
+        # https://github.com/nedbat/coveragepy/issues/1880
+        self.check_coverage("""\
+            import contextlib, itertools
+            nums = itertools.count()
+            with contextlib.nullcontext() as x, \\
+                contextlib.nullcontext() as y, \\
+                contextlib.nullcontext() as z:
+                while next(nums) < 6:
+                    y = 7
+            z = 8
+            """,
+            branchz="67 68",
+            branchz_missing="",
+        )
+
 
 class LoopArcTest(CoverageTest):
     """Arc-measuring tests involving loops."""
@@ -520,6 +535,18 @@ class LoopArcTest(CoverageTest):
             branchz_missing="",
         )
 
+    def test_missing_while_body(self) -> None:
+        self.check_coverage("""\
+            a = 3; b = 0
+            if 0:
+                while a > 0:
+                    a -= 1
+            assert a == 3 and b == 0
+            """,
+            branchz="",
+            branchz_missing="",
+        )
+
     def test_for_if_else_for(self) -> None:
         self.check_coverage("""\
             def branches_2(l):
